/*
 * Project name:
     Digital Potentiometer
 * Copyright:
     (c) Mikroelektronika, 2011.
  * Revision History
     20120418:
       - modified for EasyPIC PRO v7 (JK);
     20130627:
       - modified for EasyAVR v7 (MV);
 * Description:
     This program demonstrates the usage of Digital Potentiometer Board (MCP4161).
     Voltage derived from PW pin is read by MCU's ADC (AN2). Scaled value is then displayed at PORTD LEDs.
     User can increase or decrease resitance by pressing buttons PB2 and PB3. It's all happening in an endless loop.
 * Test configuration:
 * Test configuration:
     MCU:             ATmega32
                      http://www.atmel.com/Images/doc2503.pdf
     Dev.Board:       EasyAVR7
                      ac:EasyAVR7
                      http://www.mikroe.com/easyavr/
     Oscillator:      Oscillator Frequency 8.0000 MHz, 8.0000 MHz Crystal
     ext. modules:    DigiPot Click
                      ac:DigiPot_Click
                      http://www.mikroe.com/click/digipot/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - DigiPot Click must be connected on mikroBUS socket 1.
     - With use of wire jumpers Connect PA to Vcc, PB to Gnd and PW to PA1 pin
       Those tree (PA,PB and PW are located on DigiPot click)
     - Place PORTA PULL UP/DOWN Dip switch for PA1 pin in neutral position.
     - Turn ON PORTD LEDs (SW10.8).
     - Place Button Press Level switch (SW1) in upper position for PORTB and
       pull down PortB pins 2 and 3 (PortB three-state switch).
     - Turn ON SW5.4, SW5.5, SW5.6
*/
#include "built_in.h"

sbit DigPot_CS at PORTA5_bit;
sbit DigPot_CS_Direction at DDA5_bit;

unsigned int adc_value;
char counter;

void InitMain() {

  DDRA = 0xFD;              // Set PA1 pin as input
  DDRB = 0x00;              // Set PB2 and PB3 as input
  DDRD = 0xFF;              // Set PORTD as output

  ADC_Init();                // Initialize ADC module

  DigPot_CS = 1;
  DigPot_CS_Direction = 1;

  // Initialize SPI1 module
  SPI1_Init_Advanced(_SPI_MASTER,_SPI_FCY_DIV4,_SPI_CLK_LO_LEADING);
  adc_value = 0;
  counter = 0;
}


void main() {

  InitMain();                            // Perform main initialization
  Delay_ms(100);

  while (1) {                            // Endless loop

    DigPot_CS = 0;                       // Select PotentioMeter chip
    SPI1_Write(0);
    SPI1_Write(counter);

    SPI1_Write(0x20);
    SPI1_Write(counter);
    DigPot_CS = 1;                       // Deselect PotentioMeter chip

    adc_value = ADC_Read(1);             // Get 10-bit results of AD conversion
    PORTD = (unsigned char)(adc_value >> 2);

    if (PINB2_bit)                         // Press PB2 to decrease resistance between PW and PB
      counter ++;
    if (PINB3_bit)                         // Press PB3 to increase resistance between PW and PB
      counter --;

    Delay_ms(50);                        // Delay for debouncing

  }
}